# ima.search

IMA constitute of two primary classes which perform the biggest job, these
classes are `Search` and `Image` in `ima.search` and `ima.image` respectively.

## API reference

[ima.search](./search.md)

[ima.image](./image.md)
